-- FindParty Minimap Button
-- Based on the RBS minimap button

FP_MinimapButton = CreateFrame('Button', 'FP_MinimapButton', Minimap)

function FP_MinimapButton:Load()
	self:SetWidth(31); self:SetHeight(31)
	self:SetFrameLevel(8)
	self:RegisterForClicks('anyUp')
	self:RegisterForDrag('LeftButton')
	self:SetHighlightTexture('Interface/Minimap/UI-Minimap-ZoomButton-Highlight')

	local overlay = self:CreateTexture(nil, 'OVERLAY')
	overlay:SetWidth(53); overlay:SetHeight(53)
	overlay:SetTexture('Interface/Minimap/MiniMap-TrackingBorder')
	overlay:SetPoint('TOPLEFT')

	local icon = self:CreateTexture(nil, 'BACKGROUND')
	icon:SetWidth(20); icon:SetHeight(20)
	icon:SetTexture('Interface\\AddOns\\FindParty\\SIM-Icon')
	icon:SetTexCoord(0.05, 0.95, 0.05, 0.95)
	icon:SetPoint('TOPLEFT', 7, -5)
	self.icon = icon
	self:SetScript('OnDragStart', self.OnDragStart)
	self:SetScript('OnDragStop', self.OnDragStop)
	self:SetScript('OnMouseDown', self.OnMouseDown)
	self:SetScript('OnMouseUp', self.OnMouseUp)
	self:SetScript('OnEnter', self.OnEnter)
	self:SetScript('OnLeave', self.OnLeave)
	self:SetScript('OnClick', self.OnClick)
	self:Show()
end



function FP_MinimapButton:OnClick(button)
	if button == 'LeftButton' then
		if FP_Frame then
			if FP_Frame:IsVisible() then
				FP_Frame:Hide();
			else
				FP_Frame:Show();
			end
		end
	elseif button == 'RightButton' then
		--InterfaceOptionsFrame_OpenToCategory(FindParty.optFrame)
	end
end




function FP_MinimapButton:OnEnter()
	if not self.dragging then
		GameTooltip:SetOwner(self, 'ANCHOR_BOTTOMRIGHT')
		FP_MinimapButton:OnTooltipShow(GameTooltip)
		GameTooltip:Show()
	end
end

function FP_MinimapButton:OnTooltipShow(tooltip)
	local msg = "|cff00ff00왼쪽 클릭: |r파티찾기 도우미 열기";
	msg = msg.."\n|cff00ff00왼쪽 누르고 드래그 : |r아이콘이동";
	msg = msg.."\n|cff00ff00Alt + 왼쪽클릭: |r아이콘 고정/해제";
	msg = msg.."\n|cff00ff00Ctrl + 왼쪽클릭: |r광고 시작/정지";
	msg = msg.."\n|cff00ff00Shift + 왼쪽클릭: |r기능 정지/작동";
	msg = msg.."\n|cff00ff00오른쪽 클릭: |r옵션";
	msg = msg.."\n ";
	msg = msg.."\n현재:";
	if (FP_IsActivated()) then
		msg = msg.." 작동중";
	else
		msg = msg.." 작동정지";
	end
	if (FP_IsAnnoucing()) then
		msg = msg.." 광고중 "
	end
	if (FP_Options.iconLocked) then
		msg = msg.." 아이콘고정"
	end
		
	tooltip:AddLine(msg)

end

function FP_MinimapButton:OnLeave()
	GameTooltip:Hide()
end

function FP_MinimapButton:OnMouseDown()
	self.icon:SetTexCoord(0, 1, 0, 1)
end

function FP_MinimapButton:OnMouseUp()
	self.icon:SetTexCoord(0.05, 0.95, 0.05, 0.95)
end

function FP_MinimapButton:OnDragStart()
	self.dragging = true
	self:LockHighlight()
	self.icon:SetTexCoord(0, 1, 0, 1)
	self:SetScript('OnUpdate', self.OnUpdate)
	GameTooltip:Hide()
end

function FP_MinimapButton:OnDragStop()
	self.dragging = nil
	self:SetScript('OnUpdate', nil)
	self.icon:SetTexCoord(0.05, 0.95, 0.05, 0.95)
	self:UnlockHighlight()
end


function FP_MinimapButton:OnUpdate()
	local mx, my = Minimap:GetCenter()
	local px, py = GetCursorPosition()
	local scale = Minimap:GetEffectiveScale()
	px, py = px / scale, py / scale
	FindParty.db.profile.MiniMapAngle = math.deg(math.atan2(py - my, px - mx)) % 360
	self:UpdatePosition()
end


function FP_MinimapButton:UpdatePosition()
	local angle = math.rad(FindParty.db.profile.MiniMapAngle)
	local cos = math.cos(angle)
	local sin = math.sin(angle)
	local minimapShape = GetMinimapShape and GetMinimapShape() or 'ROUND'

	local round = false
	if minimapShape == 'ROUND' then
		round = true
	elseif minimapShape == 'SQUARE' then
		round = false
	elseif minimapShape == 'CORNER-TOPRIGHT' then
		round = not(cos < 0 or sin < 0)
	elseif minimapShape == 'CORNER-TOPLEFT' then
		round = not(cos > 0 or sin < 0)
	elseif minimapShape == 'CORNER-BOTTOMRIGHT' then
		round = not(cos < 0 or sin > 0)
	elseif minimapShape == 'CORNER-BOTTOMLEFT' then
		round = not(cos > 0 or sin > 0)
	elseif minimapShape == 'SIDE-LEFT' then
		round = cos <= 0
	elseif minimapShape == 'SIDE-RIGHT' then
		round = cos >= 0
	elseif minimapShape == 'SIDE-TOP' then
		round = sin <= 0
	elseif minimapShape == 'SIDE-BOTTOM' then
		round = sin >= 0
	elseif minimapShape == 'TRICORNER-TOPRIGHT' then
		round = not(cos < 0 and sin > 0)
	elseif minimapShape == 'TRICORNER-TOPLEFT' then
		round = not(cos > 0 and sin > 0)
	elseif minimapShape == 'TRICORNER-BOTTOMRIGHT' then
		round = not(cos < 0 and sin < 0)
	elseif minimapShape == 'TRICORNER-BOTTOMLEFT' then
		round = not(cos > 0 and sin < 0)
	end

	local x, y
	if round then
		x = cos*80
		y = sin*80
	else
		x = math.max(-82, math.min(110*cos, 84))
		y = math.max(-86, math.min(110*sin, 82))
	end

	self:SetPoint('CENTER', x, y)
end

FP_MinimapButton:Load()
